collisionBehavior property
Indicates how the marker behaves when it collides with other markers.
Implementation
final MarkerCollisionBehavior collisionBehavior;
Indicates how the marker behaves when it collides with other markers.
final MarkerCollisionBehavior collisionBehavior;