hideMarkerInfoWindow method
Programmatically hide the Info Window for a Marker.
The markerId must match one of the markers on the map.
An invalid markerId triggers an "Invalid markerId" error.
- See also:
- showMarkerInfoWindow to show the Info Window.
- isMarkerInfoWindowShown to check if the Info Window is showing.
Implementation
Future<void> hideMarkerInfoWindow(MarkerId markerId) {
_checkWidgetMountedOrThrow();
return GoogleMapsFlutterPlatform.instance.hideMarkerInfoWindow(
markerId,
mapId: mapId,
);
}