PinConfig constructor

const PinConfig({
  1. Color? backgroundColor,
  2. Color? borderColor,
  3. AdvancedMarkerGlyph? glyph,
})

Constructs a PinConfig that is created from a pin configuration.

The backgroundColor and borderColor are used to define the color of the standard pin marker.

The glyph parameter is used to define the glyph that is displayed on the pin marker.

At least one of the parameters must not be null.

WARNING: On iOS, using a PinConfig may result in the marker not showing. For details and updates, see https://issuetracker.google.com/issues/370536110. If this issue has not been fixed in the version of the Google Maps SDK you are using, consider using an asset or bitmap for customization on iOS.

Implementation

const PinConfig({this.backgroundColor, this.borderColor, this.glyph})
  : assert(
      backgroundColor != null || borderColor != null || glyph != null,
      'Cannot create PinConfig with all parameters being null.',
    ),
    super._();