getLatLng method
Returns LatLng corresponding to the ScreenCoordinate in the current map view.
Returned LatLng corresponds to a screen location. The screen location is specified in screen pixels (not display pixels) relative to the top left of the map, not top left of the whole screen.
Implementation
Future<LatLng> getLatLng(ScreenCoordinate screenCoordinate) {
_checkWidgetMountedOrThrow();
return GoogleMapsFlutterPlatform.instance.getLatLng(
screenCoordinate,
mapId: mapId,
);
}