onEdited property
Called when the user edits the polygon path by dragging vertices.
The callback receives the updated outer boundary points and the updated list of holes. Only fires when editable is true. Currently only supported on web.
Implementation
final void Function(List<LatLng> points, List<List<LatLng>> holes)? onEdited;