editable property
True if the user can edit this polyline by dragging its vertices.
When true, the polyline renders with draggable vertex handles. Currently only supported on web.
Implementation
final bool editable;
True if the user can edit this polyline by dragging its vertices.
When true, the polyline renders with draggable vertex handles. Currently only supported on web.
final bool editable;